package ru.myitschool.work.ui.profile

import android.os.Bundle
import android.view.View
import androidx.fragment.app.Fragment
import androidx.fragment.app.viewModels
import androidx.navigation.fragment.findNavController
import androidx.swiperefreshlayout.widget.SwipeRefreshLayout
import com.squareup.picasso.Picasso
import ru.myitschool.work.R
import ru.myitschool.work.databinding.FragmentUserBinding
import ru.myitschool.work.utils.collectWithLifecycle
import ru.myitschool.work.utils.visibleOrGone

class UserFragment : Fragment(R.layout.fragment_user) {

    private var _binding: FragmentUserBinding? = null
    private val binding: FragmentUserBinding get() = _binding!!

    private val viewModel by viewModels<UserViewModel> { UserViewModel.Factory }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        _binding = FragmentUserBinding.bind(view)

        viewModel.state.collectWithLifecycle(this) { state ->
            (binding.refresh as SwipeRefreshLayout).isRefreshing =
                state is UserViewModel.State.Loading
            binding.content?.visibleOrGone(state is UserViewModel.State.Show)
            when (state) {
                is UserViewModel.State.Loading -> Unit
                is UserViewModel.State.Show -> {
                    val user = state.userEntity
                    binding.fullname.text = user.name
                    binding.position.text = user.position
                    binding.lastEntry.text = user.lastVisit
                    Picasso.get().load(user.photoUrl).into(binding.photo)
                }
            }

            (binding.refresh as SwipeRefreshLayout).setOnRefreshListener {
                viewModel.onRefresh()
            }

            binding.logout.setOnClickListener {
                viewModel.onLogout()
                findNavController().navigate(R.id.action_userFragment_to_loginFragment)
            }
        }
    }

    override fun onDestroy() {
        _binding = null
        super.onDestroy()
    }
}